==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/equipment/bauble/TinyPlanetItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.bauble;

import com.google.common.base.Predicates;
import vazkii.botania.api.internal.ManaBurst;
import vazkii.botania.api.mana.TinyPlanetExcempt;
import vazkii.botania.client.render.AccessoryRenderRegistry;
import vazkii.botania.client.render.AccessoryRenderer;
import vazkii.botania.common.block.BotaniaBlocks;
import vazkii.botania.common.proxy.Proxy;

import java.util.List;
import net.minecraft.class_1309;
import net.minecraft.class_1682;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_572;

public class TinyPlanetItem extends BaubleItem {

	public TinyPlanetItem(class_1793 props) {
		super(props);
		Proxy.INSTANCE.runOnClient(() -> () -> AccessoryRenderRegistry.register(this, new Renderer()));
	}

	@Override
	public void onWornTick(class_1799 stack, class_1309 living) {
		double x = living.method_23317();
		double y = living.method_23318() + living.method_5751();
		double z = living.method_23321();

		applyEffect(living.field_6002, x, y, z);
	}

	public static class Renderer implements AccessoryRenderer {
		@Override
		public void doRender(class_572<?> bipedModel, class_1799 stack, class_1309 living, class_4587 ms, class_4597 buffers, int light, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
			bipedModel.field_3398.method_22703(ms);
			ms.method_22904(-0.25, -0.4, 0);
			ms.method_22905(0.5F, -0.5F, -0.5F);
			class_310.method_1551().method_1541().method_3353(BotaniaBlocks.tinyPlanet.method_9564(), ms, buffers, light, class_4608.field_21444);
		}
	}

	public static void applyEffect(class_1937 world, double x, double y, double z) {
		int range = 8;
		List<class_1682> entities = world.method_8390(class_1682.class, new class_238(x - range, y - range, z - range, x + range, y + range, z + range), Predicates.instanceOf(ManaBurst.class));
		for (class_1682 entity : entities) {
			ManaBurst burst = (ManaBurst) entity;
			class_1799 lens = burst.getSourceLens();
			if (lens != null && lens.method_7909() instanceof TinyPlanetExcempt excempt && !excempt.shouldPull(lens)) {
				continue;
			}

			int orbitTime = burst.getOrbitTime();
			if (orbitTime == 0) {
				burst.setMinManaLoss(burst.getMinManaLoss() * 3);
			}

			float radius = Math.min(7.5F, (Math.max(40, orbitTime) - 40) / 40F + 1.5F);
			int angle = orbitTime % 360;

			float xTarget = (float) (x + Math.cos(angle * 10 * Math.PI / 180F) * radius);
			float yTarget = (float) y;
			float zTarget = (float) (z + Math.sin(angle * 10 * Math.PI / 180F) * radius);

			class_243 targetVec = new class_243(xTarget, yTarget, zTarget);
			class_243 currentVec = entity.method_19538();
			class_243 moveVector = targetVec.method_1020(currentVec);

			entity.method_18799(moveVector);

			burst.setOrbitTime(burst.getOrbitTime() + 1);
		}
	}

}

==> Botania-1.20.1-451-FABRIC-20251019.112919-17-sources.jar: vazkii/botania/common/item/equipment/bauble/TinyPlanetItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.bauble;

import com.google.common.base.Predicates;
import vazkii.botania.api.internal.ManaBurst;
import vazkii.botania.api.mana.TinyPlanetExcempt;
import vazkii.botania.client.render.AccessoryRenderRegistry;
import vazkii.botania.client.render.AccessoryRenderer;
import vazkii.botania.common.block.BotaniaBlocks;
import vazkii.botania.common.proxy.Proxy;

import java.util.List;
import net.minecraft.class_1309;
import net.minecraft.class_1682;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_572;

public class TinyPlanetItem extends BaubleItem {

	public TinyPlanetItem(class_1793 props) {
		super(props);
		Proxy.INSTANCE.runOnClient(() -> () -> AccessoryRenderRegistry.register(this, new Renderer()));
	}

	@Override
	public void onWornTick(class_1799 stack, class_1309 living) {
		double x = living.method_23317();
		double y = living.method_23318() + living.method_5751();
		double z = living.method_23321();

		applyEffect(living.method_37908(), x, y, z);
	}

	public static class Renderer implements AccessoryRenderer {
		@Override
		public void doRender(class_572<?> bipedModel, class_1799 stack, class_1309 living, class_4587 ms, class_4597 buffers, int light, float limbSwing, float limbSwingAmount, float partialTicks, float ageInTicks, float netHeadYaw, float headPitch) {
			bipedModel.field_3398.method_22703(ms);
			ms.method_22904(-0.25, -0.4, 0);
			ms.method_22905(0.5F, -0.5F, -0.5F);
			class_310.method_1551().method_1541().method_3353(BotaniaBlocks.tinyPlanet.method_9564(), ms, buffers, light, class_4608.field_21444);
		}
	}

	public static void applyEffect(class_1937 world, double x, double y, double z) {
		int range = 8;
		List<class_1682> entities = world.method_8390(class_1682.class, new class_238(x - range, y - range, z - range, x + range, y + range, z + range), Predicates.instanceOf(ManaBurst.class));
		for (class_1682 entity : entities) {
			ManaBurst burst = (ManaBurst) entity;
			class_1799 lens = burst.getSourceLens();
			if (lens != null && lens.method_7909() instanceof TinyPlanetExcempt excempt && !excempt.shouldPull(lens)) {
				continue;
			}

			int orbitTime = burst.getOrbitTime();
			if (orbitTime == 0) {
				burst.setMinManaLoss(burst.getMinManaLoss() * 3);
			}

			float radius = Math.min(7.5F, (Math.max(40, orbitTime) - 40) / 40F + 1.5F);
			int angle = orbitTime % 360;

			float xTarget = (float) (x + Math.cos(angle * 10 * Math.PI / 180F) * radius);
			float yTarget = (float) y;
			float zTarget = (float) (z + Math.sin(angle * 10 * Math.PI / 180F) * radius);

			class_243 targetVec = new class_243(xTarget, yTarget, zTarget);
			class_243 currentVec = entity.method_19538();
			class_243 moveVector = targetVec.method_1020(currentVec);

			entity.method_18799(moveVector);

			burst.setOrbitTime(burst.getOrbitTime() + 1);
		}
	}

}
